@@ -18,6 +18,7 @@ class Printer:
         self.tempdevcount = 0
         self.fancount = 0
         self.ledcount = 0
+        self.pwm_tools_count = 0
         self.output_pin_count = 0
         self.store_timeout = None
         self.tempstore = {}
@@ -27,6 +28,7 @@ class Printer:
         self.spoolman = False
         self.temp_devices = self.sensors = None
         self.system_info = {}
+        self.warnings = []
 
     def reinit(self, printer_info, data):
         self.config = data['configfile']['config']
@@ -37,76 +39,71 @@ class Printer:
         self.fancount = 0
         self.ledcount = 0
         self.output_pin_count = 0
+        self.pwm_tools_count = 0
         self.tempstore.clear()
         self.tempstore_size = 1200
         self.available_commands.clear()
         self.temp_devices = self.sensors = None
         self.stop_tempstore_updates()
         self.system_info.clear()
+        self.warnings = []
 
         for x in self.config.keys():
-            if x[:8] == "extruder":
+            # Support for hiding devices by name
+            section, _, name = x.partition(" ")
+            if name.startswith("_"):
+                continue
+
+            if section.startswith("extruder"):
                 self.tools.append(x)
-                self.tools = sorted(self.tools)
                 self.extrudercount += 1
-                if x.startswith('extruder_stepper'):
+                if name.startswith("extruder_stepper"):
                     continue
-                self.data[x] = {
-                    "temperature": 0,
-                    "target": 0
-                }
-            if x == 'heater_bed' \
-                    or x.startswith('heater_generic ') \
-                    or x.startswith('temperature_sensor ') \
-                    or x.startswith('temperature_fan '):
+                self.data[x] = {"temperature": 0, "target": 0}
+            elif section in (
+                "heater_bed",
+                "heater_generic",
+                "temperature_sensor",
+                "temperature_fan"
+            ):
                 self.data[x] = {"temperature": 0}
-                if not x.startswith('temperature_sensor '):
+                if section != "temperature_sensor":
                     self.data[x]["target"] = 0
-                # Support for hiding devices by name
-                name = x.split()[1] if len(x.split()) > 1 else x
-                if not name.startswith("_"):
-                    self.tempdevcount += 1
-            if x == 'fan' \
-                    or x.startswith('controller_fan ') \
-                    or x.startswith('heater_fan ') \
-                    or x.startswith('fan_generic '):
-                # Support for hiding devices by name
-                name = x.split()[1] if len(x.split()) > 1 else x
-                if not name.startswith("_"):
-                    self.fancount += 1
-            if x.startswith('output_pin ') and not x.split()[1].startswith("_"):
+                self.tempdevcount += 1
+            elif section in (
+                "fan",
+                "controller_fan",
+                "heater_fan",
+                "fan_generic"
+            ):
+                self.fancount += 1
+            elif section == "output_pin":
                 self.output_pin_count += 1
-            if x.startswith('bed_mesh '):
-                try:
-                    r = self.config[x]
-                    r['x_count'] = int(r['x_count'])
-                    r['y_count'] = int(r['y_count'])
-                    r['max_x'] = float(r['max_x'])
-                    r['min_x'] = float(r['min_x'])
-                    r['max_y'] = float(r['max_y'])
-                    r['min_y'] = float(r['min_y'])
-                    r['points'] = [[float(j.strip()) for j in i.split(",")] for i in r['points'].strip().split("\n")]
-                except KeyError:
-                    logging.debug(f"Couldn't load mesh {x}: {self.config[x]}")
-            if x.startswith('led') \
-                    or x.startswith('neopixel ') \
-                    or x.startswith('dotstar ') \
-                    or x.startswith('pca9533 ') \
-                    or x.startswith('pca9632 '):
-                name = x.split()[1] if len(x.split()) > 1 else x
-                if not name.startswith("_"):
-                    self.ledcount += 1
+            elif section == "pwm_tool":
+                self.pwm_tools_count += 1
+            elif section in (
+                "led",
+                "neopixel",
+                "dotstar",
+                "pca9533",
+                "pca9632"
+            ):
+                self.ledcount += 1
+
+        self.tools = sorted(self.tools)
+        self.log_counts(printer_info)
         self.process_update(data)
 
+    def log_counts(self, printer_info):
         logging.info(f"Klipper version: {printer_info['software_version']}")
         logging.info(f"# Extruders: {self.extrudercount}")
         logging.info(f"# Temperature devices: {self.tempdevcount}")
         logging.info(f"# Fans: {self.fancount}")
         logging.info(f"# Output pins: {self.output_pin_count}")
+        logging.info(f"# PWM tools: {self.pwm_tools_count}")
         logging.info(f"# Leds: {self.ledcount}")
 
     def stop_tempstore_updates(self):
-        logging.info("Stopping tempstore")
         if self.store_timeout is not None:
             GLib.source_remove(self.store_timeout)
             self.store_timeout = None
@@ -116,8 +113,11 @@ class Printer:
             return
 
         for x in data:
-            if x == "configfile" and 'config' in data[x]:
-                self.config.update(data[x]['config'])
+            if x == "configfile":
+                if 'config' in data[x]:
+                    self.config.update(data[x]['config'])
+                if 'warnings' in data[x]:
+                    self.warnings = data[x]['warnings']
             if x not in self.data:
                 self.data[x] = {}
             self.data[x].update(data[x])
@@ -233,7 +233,7 @@ class Printer:
         return self.sensors
 
     def get_probe(self):
-        probe_types = ["probe", "bltouch", "smart_effector", "dockable_probe"]
+        probe_types = ["probe", "bltouch", "smart_effector", "probe_eddy_current"]
         for probe_type in probe_types:
             if self.config_section_exists(probe_type):
                 logging.info(f"Probe type: {probe_type}")
@@ -253,9 +253,10 @@ class Printer:
                 "temperature_devices": {"count": self.tempdevcount},
                 "fans": {"count": self.fancount},
                 "output_pins": {"count": self.output_pin_count},
+                "pwm_tools": {"count": self.pwm_tools_count},
                 "gcode_macros": {"count": len(self.get_gcode_macros()), "list": self.get_gcode_macros()},
                 "leds": {"count": self.ledcount},
-                "config_sections": [section for section in self.config.keys()],
+                "config_sections": list(self.config.keys()),
             }
         }
 
