@@ -14,7 +14,8 @@ class Panel(ScreenPanel):
     graph_update = None
     active_heater = None
 
-    def __init__(self, screen, title, extra=None):
+    def __init__(self, screen, title, **kwargs):
+        title = title or _("Temperature")
         super().__init__(screen, title)
         self.left_panel = None
         self.devices = {}
@@ -25,29 +26,11 @@ class Panel(ScreenPanel):
         self.h = self.f = 0
         self.tempdeltas = ["1", "5", "10", "25"]
         self.tempdelta = self.tempdeltas[-2]
-        self.show_preheat = False
+        self.show_preheat = self._printer.state not in ("printing", "paused")
         self.preheat_options = self._screen._config.get_preheat_options()
         self.grid = Gtk.Grid(row_homogeneous=True, column_homogeneous=True)
         self._gtk.reset_temp_color()
-
-        # When printing start in temp_delta mode and only select tools
-        selection = []
-        if self._printer.state not in ("printing", "paused"):
-            self.show_preheat = True
-            selection.extend(self._printer.get_temp_devices())
-        elif extra:
-            selection.append(extra)
-
-        # Select heaters
-        for h in selection:
-            if h.startswith("temperature_sensor "):
-                continue
-            name = h.split()[1] if len(h.split()) > 1 else h
-            # Support for hiding devices by name
-            if name.startswith("_"):
-                continue
-            if h not in self.active_heaters:
-                self.select_heater(None, h)
+        self.extra_selection = None
 
         if self._screen.vertical_mode:
             self.grid.attach(self.create_left_panel(), 0, 0, 1, 3)
@@ -223,6 +206,31 @@ class Panel(ScreenPanel):
         if not self._printer.tempstore:
             self._screen.init_tempstore()
         self.update_graph_visibility()
+        self.set_selection()
+
+    def set_extra(self, extra=None, **kwargs):
+        self.extra_selection = extra
+
+    def set_selection(self):
+        selection = []
+        if self.extra_selection:
+            selection.append(self.extra_selection)
+        elif self._printer.state not in ("printing", "paused"):
+            selection.extend(self._printer.get_temp_devices())
+        elif 'toolhead' in self._printer.data and 'extruder' in self._printer.data['toolhead']:
+            current_extruder = self._printer.data['toolhead']['extruder']
+            selection.append(current_extruder)
+
+        for heater in self.active_heaters:
+            if heater not in selection:
+                self.select_heater(None, heater)
+        for heater in selection:
+            if heater.startswith("temperature_sensor "):
+                continue
+            name = heater.split()[1] if len(heater.split()) > 1 else heater
+            if heater not in self.active_heaters:
+                self.select_heater(None, heater)
+        self.extra_selection = None
 
     def deactivate(self):
         if self.graph_update is not None:
@@ -378,6 +386,7 @@ class Panel(ScreenPanel):
 
         self.labels["da"].add_object(device, "temperatures", rgb, False, False)
         temp = self._gtk.Button(label="", lines=1)
+        find_widget(temp, Gtk.Label).set_ellipsize(False)
 
         if self._printer.device_has_target(device):
             temp.connect("clicked", self.show_numpad, device)
@@ -484,14 +493,15 @@ class Panel(ScreenPanel):
         return max(temp, 0)
 
     def pid_calibrate(self, temp):
+        heater = self.active_heater.split(' ', maxsplit=1)[-1]
         if self.verify_max_temp(temp):
             script = {
-                "script": f"PID_CALIBRATE HEATER={self.active_heater} TARGET={temp}"
+                "script": f"PID_CALIBRATE HEATER={heater} TARGET={temp}"
             }
             self._screen._confirm_send_action(
                 None,
                 _("Initiate a PID calibration for:")
-                + f" {self.active_heater} @ {temp} ºC"
+                + f" {heater} @ {temp} ºC"
                 + "\n\n"
                 + _("It may take more than 5 minutes depending on the heater power."),
                 "printer.gcode.script",
@@ -505,7 +515,6 @@ class Panel(ScreenPanel):
 
         name = Gtk.Label()
         temp = Gtk.Label(_("Temp (°C)"))
-        temp.get_style_context().add_class("heater-grid-temp")
 
         self.labels["devices"].attach(name, 0, 0, 1, 1)
         self.labels["devices"].attach(temp, 1, 0, 1, 1)
